@@ -1,6 +1,6 @@
 from nose.tools import assert_equals, assert_true
 
-from pretenders.http.client import CaseInsensitiveDict
+from pretenders.http import CaseInsensitiveDict
 
 
 def test_caseinsensitivedict_creation():
